
# Slot: subject


A variant that has a role in modeling the disease.

URI: [biolink:variant_as_a_model_of_disease_association_subject](https://w3id.org/biolink/vocab/variant_as_a_model_of_disease_association_subject)


## Domain and Range

[VariantAsAModelOfDiseaseAssociation](VariantAsAModelOfDiseaseAssociation.md) &#8594;  <sub>1..1</sub> [SequenceVariant](SequenceVariant.md)

## Parents

 *  is_a: [variant to disease association➞subject](variant_to_disease_association_subject.md)

## Children


## Used by

 * [VariantAsAModelOfDiseaseAssociation](VariantAsAModelOfDiseaseAssociation.md)
